
#include "stm32f10x.h"
#include "step_motor.h"

int main(void) {
    // 初始化步进电机控制
    StepperMotor_Init();

    // 定义步进电机结构体
    StepMotor motor = {
        .stepcount = 0,          // 初始步数
        .direction = 1,          // 初始方向（1：顺时针）
        .curSpeed = 0,           // 初始速度为0
        .desSpeed = 0,           // 目标速度
        .maxSpeed = 9375,        // 最大转速（假设值）
        .speedStatus = SPEED_NONE, // 初始速度状态
        .stepcountMode = 0,      // 脉冲计数模式
        .curlocation = 0,        // 当前位置
        .deslocation = 0,        // 目标位置
        .acceleration = 1000,    // 加速度 (步/秒^2)
        .deceleration = 1000,    // 减速度 (步/秒^2)
        .psc = 71,               // 预分频器
        .arr = 999               // 自动重装载寄存器
    };

    // 初始化定时器 TIM3
    TIM3_Init(motor.psc, motor.arr);

    // 设置初始方向（例如顺时针）
    Set_Direction(motor.direction);

    // 使能步进电机
    Enable_Stepper(true);

    // 主循环
    while (1) {
        // 例子：加速到目标速度
        Update_Motor_Status(&motor, SPEED_ACC, 9375, 1000); // 以1000 RPM/s的加速度加速到9375 RPM

        // 保持匀速一段时间
        Delay(5000); // 延时5秒

        // 例子：减速到停止
        Update_Motor_Status(&motor, SPEED_DEC, 0, 1000); // 以1000 RPM/s的减速度减速到停止

        // 保持停止一段时间
        Delay(5000); // 延时5秒
    }
}